@@ -34,7 +34,17 @@ fn main() -> ! {
     let clock_cfg = Clocks {
         input_src: InputSrc::Hsi,
         stop_wuck: StopWuck::Hsi,
-        ..Clocks::default()
+        ..Default::default()
+    };
+
+    // Here's an example clock config, where you're using a 16Mhz SMD oscillator, and are using
+    // the internal HSI48 for USB:
+    let clock_cfg = Clocks {
+        input_src: InputSrc::Pll(PllSrc::Hse(16_000_000)),
+        hse_bypass: true,
+        hsi48_on: true,
+        clk48_src: Clk48Src::Hsi48,
+        ..Default::default()
     };
 
     // Set it up to use the HSI, with no PLL. This will result in a reduced speed:
@@ -90,10 +100,9 @@ fn main() -> ! {
         .ccipr
         .modify(|_, w| unsafe { w.i2c1sel().bits(0b10) });
 
-    // Configure clock registers.
-    if clock_cfg.setup(&mut dp.RCC, &mut dp.FLASH).is_err() {
-        defmt::error!("Unable to configure clocks due to a speed error.")
-    };
+    // Configure clock registers. The previous creation and modification of `clock_cfg`
+    // only set up a configuration struct; `Clocks::setup` performs the MCU operations.
+    clock_cfg.setup(&mut dp.RCC, &mut dp.FLASH).unwrap();
 
     // Show speeds.
     defmt::info!("Speeds: {:?}", clock_cfg.calc_speeds());
