@@ -1,10 +1,9 @@
 //! Clock config for STM32L, G, and W-series MCUs
 
 use crate::{
-    clocks::SpeedError,
+    clocks::{ClocksValid, SpeedError},
     pac::{self, FLASH, RCC},
     rcc_en_reset,
-    traits::{ClockCfg, ClocksValid},
 };
 
 use cfg_if::cfg_if;
@@ -12,7 +11,7 @@ use cfg_if::cfg_if;
 // todo: WB is missing second LSI2, and perhaps other things.
 // todo: Mix H7 clocks into this module.
 
-#[cfg(not(feature = "g0"))]
+#[cfg(not(any(feature = "g0", feature = "wl")))]
 #[derive(Clone, Copy, PartialEq)]
 #[repr(u8)]
 pub enum Clk48Src {
@@ -52,7 +51,7 @@ pub enum PllSrc {
     Hse(u32),
 }
 
-#[cfg(any(feature = "l4", feature = "l5", feature = "wb"))]
+#[cfg(any(feature = "l4", feature = "l5", feature = "wb", feature = "wl"))]
 #[derive(Clone, Copy, PartialEq)]
 #[repr(u8)]
 /// Select the system clock used when exiting Stop mode
@@ -70,7 +69,9 @@ enum WaitState {
     W0 = 0,
     W1 = 1,
     W2 = 2,
+    #[cfg(not(feature = "wl"))]
     W3 = 3,
+    #[cfg(not(any(feature = "wb", feature = "wl")))]
     W4 = 4,
     #[cfg(feature = "l5")]
     W5 = 5,
@@ -79,6 +80,7 @@ enum WaitState {
 impl PllSrc {
     /// Required due to numerical value on non-uniform discrim being experimental.
     /// (ie, can't set on `Pll(Pllsrc)`.
+    /// Sets PLLCFGR reg (PLLSYSCFGR on G0), PLLSRC field.
     pub fn bits(&self) -> u8 {
         // L4 RM, 6.4.4
         #[cfg(not(any(feature = "g0", feature = "g4")))]
@@ -233,7 +235,7 @@ impl Prediv {
     }
 }
 
-#[cfg(not(feature = "g4"))]
+#[cfg(not(any(feature = "l5", feature = "g4")))]
 #[derive(Clone, Copy)]
 #[repr(u8)]
 pub enum Pllm {
@@ -247,7 +249,7 @@ pub enum Pllm {
     Div8 = 0b111,
 }
 
-#[cfg(feature = "g4")]
+#[cfg(any(feature = "l5", feature = "g4"))]
 #[derive(Clone, Copy)]
 #[repr(u8)]
 pub enum Pllm {
@@ -271,7 +273,7 @@ pub enum Pllm {
 
 impl Pllm {
     pub fn value(&self) -> u8 {
-        #[cfg(not(feature = "g4"))]
+        #[cfg(not(any(feature = "l5", feature = "g4")))]
         match self {
             Self::Div1 => 1,
             Self::Div2 => 2,
@@ -283,7 +285,7 @@ impl Pllm {
             Self::Div8 => 8,
         }
 
-        #[cfg(feature = "g4")]
+        #[cfg(any(feature = "l5", feature = "g4"))]
         match self {
             Self::Div1 => 1,
             Self::Div2 => 2,
@@ -305,7 +307,7 @@ impl Pllm {
     }
 }
 
-#[cfg(feature = "g0")]
+#[cfg(any(feature = "g0", feature = "wb"))]
 #[derive(Clone, Copy)]
 #[repr(u8)]
 // Main PLL division factor for PLLCLK (system clock).
@@ -319,7 +321,7 @@ pub enum Pllr {
     Div8 = 0b111,
 }
 
-#[cfg(feature = "g0")]
+#[cfg(any(feature = "g0", feature = "wb"))]
 impl Pllr {
     pub fn value(&self) -> u8 {
         match self {
@@ -334,7 +336,7 @@ impl Pllr {
     }
 }
 
-#[cfg(not(feature = "g0"))]
+#[cfg(not(any(feature = "g0", feature = "wb")))]
 #[derive(Clone, Copy)]
 #[repr(u8)]
 // Main PLL division factor for PLLCLK (system clock). G4 RM 7.4.4. Also used to set PLLQ.
@@ -345,7 +347,7 @@ pub enum Pllr {
     Div8 = 0b11,
 }
 
-#[cfg(not(feature = "g0"))]
+#[cfg(not(any(feature = "g0", feature = "wb")))]
 impl Pllr {
     pub fn value(&self) -> u8 {
         match self {
@@ -360,8 +362,19 @@ impl Pllr {
 #[derive(Clone, Copy)]
 #[repr(u8)]
 /// Division factor for the AHB clock. Also known as AHB Prescaler. L4 RM, 6.4.3
+/// on WB, used for all 3 HCLK prescalers.
 pub enum HclkPrescaler {
     Div1 = 0b0000,
+    #[cfg(feature = "wb")]
+    Div3 = 0b0001,
+    #[cfg(feature = "wb")]
+    Div5 = 0b0010,
+    #[cfg(feature = "wb")]
+    Div6 = 0b0101,
+    #[cfg(feature = "wb")]
+    Div10 = 0b0110,
+    #[cfg(feature = "wb")]
+    Div32 = 0b0111,
     Div2 = 0b1000,
     Div4 = 0b1001,
     Div8 = 0b1010,
@@ -376,6 +389,16 @@ impl HclkPrescaler {
     pub fn value(&self) -> u16 {
         match self {
             Self::Div1 => 1,
+            #[cfg(feature = "wb")]
+            Self::Div3 => 3,
+            #[cfg(feature = "wb")]
+            Self::Div5 => 5,
+            #[cfg(feature = "wb")]
+            Self::Div6 => 6,
+            #[cfg(feature = "wb")]
+            Self::Div10 => 10,
+            #[cfg(feature = "wb")]
+            Self::Div32 => 32,
             Self::Div2 => 2,
             Self::Div4 => 4,
             Self::Div8 => 8,
@@ -417,9 +440,9 @@ pub struct Clocks {
     pub input_src: InputSrc, //
     pub pllm: Pllm, // PLL divider
     pub plln: u8,   // PLL multiplier. Valid range of 7 to 86.
-    #[cfg(not(any(feature = "g0", feature = "g4")))]
+    #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))]
     pub pll_sai1_mul: u8, // PLL SAI1 multiplier. Valid range of 7 to 86.
-    #[cfg(not(any(feature = "g0", feature = "g4")))]
+    #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))]
     pub pll_sai2_mul: u8, // PLL SAI2 multiplier. Valid range of 7 to 86.
     pub pllr: Pllr,
     pub pllq: Pllr,
@@ -428,6 +451,9 @@ pub struct Clocks {
     #[cfg(feature = "wb")]
     /// The value to divide SYSCLK by for HCLK2. (CPU2)
     pub hclk2_prescaler: HclkPrescaler,
+    #[cfg(feature = "wl")]
+    /// The value to divide SYSCLK by for HCLK3.
+    pub hclk3_prescaler: HclkPrescaler,
     #[cfg(feature = "wb")]
     /// The value to divide SYSCLK by for HCLK4.
     pub hclk4_prescaler: HclkPrescaler,
@@ -438,21 +464,21 @@ pub struct Clocks {
     pub apb2_prescaler: ApbPrescaler,
     // Bypass the HSE output, for use with oscillators that don't need it. Saves power, and
     // frees up the pin for use as GPIO.
-    #[cfg(not(any(feature = "g0")))]
+    #[cfg(not(any(feature = "g0", feature = "wl")))]
     /// The input source for the 48Mhz clock used by USB.
     pub clk48_src: Clk48Src,
-    #[cfg(not(any(feature = "g0", feature = "g4")))]
+    #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))]
     pub sai1_enabled: bool,
-    #[cfg(not(any(feature = "g0", feature = "g4")))]
+    #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))]
     pub sai2_enabled: bool,
     /// Bypass the HSE output, for use with oscillators that don't need it. Saves power, and
     /// frees up the pin for use as GPIO.
     pub hse_bypass: bool,
     pub security_system: bool,
-    #[cfg(not(feature = "g0"))]
+    #[cfg(not(any(feature = "g0", feature = "wl")))]
     /// Enable the HSI48. For L4, this is only applicable for some devices.
     pub hsi48_on: bool,
-    #[cfg(any(feature = "l4", feature = "l5", feature = "wb"))]
+    #[cfg(any(feature = "l4", feature = "l5", feature = "wb", feature = "wl"))]
     /// Select the input source to use after waking up from `stop` mode. Eg HSI or MSI.
     pub stop_wuck: StopWuck,
 }
@@ -473,7 +499,15 @@ impl Clocks {
         // We need to do this before enabling PLL, or it won't enable.
         let (_, sysclk) = self.calc_sysclock();
 
-        let hclk = sysclk / self.hclk_prescaler.value() as u32;
+        cfg_if! {
+            if #[cfg(feature = "wb")] {
+                let hclk = sysclk / self.hclk4_prescaler.value() as u32;
+            } else if #[cfg(feature = "wl")] {
+                let hclk = sysclk / self.hclk3_prescaler.value() as u32;
+            } else {
+                let hclk = sysclk / self.hclk_prescaler.value() as u32;
+            }
+        }
 
         // TODO: these are only implemented for Vcore Rnage 1 (Normal mode as applicable)
         // todo: Other modes, like MODE 2 (For lower max system clocks) on L4.
@@ -518,7 +552,31 @@ impl Clocks {
                     } else {
                         w.latency().bits(WaitState::W2 as u8)
                     }
-                })
+                });
+            } else if #[cfg(feature = "wb")] {  // WB. RM section 3.3.4, Table 4.
+            // Note: This applies to HCLK4 HCLK. (See HCLK4 used above for hclk var.)
+                flash.acr.modify(|_, w| unsafe {
+                    if hclk <= 18_000_000 {
+                        w.latency().bits(WaitState::W0 as u8)
+                    } else if hclk <= 36_000_000 {
+                        w.latency().bits(WaitState::W1 as u8)
+                    } else if hclk <= 54_000_000 {
+                        w.latency().bits(WaitState::W2 as u8)
+                    } else {
+                        w.latency().bits(WaitState::W3 as u8)
+                    }
+                });
+            } else if #[cfg(any(feature = "wb", feature = "wl"))] {  // WL. RM section 3.3.4, Table 5.
+            // Note: This applies to HCLK3 HCLK. (See HCLK3 used above for hclk var.)
+                flash.acr.modify(|_, w| unsafe {
+                    if hclk <= 18_000_000 {
+                        w.latency().bits(WaitState::W0 as u8)
+                    } else if hclk <= 36_000_000 {
+                        w.latency().bits(WaitState::W1 as u8)
+                    } else {
+                        w.latency().bits(WaitState::W2 as u8)
+                    }
+                });
             } else {  // G4. RM section 3.3.3
                 flash.acr.modify(|_, w| unsafe {
                     if hclk <= 34_000_000 {
@@ -565,7 +623,7 @@ impl Clocks {
 
                 rcc.cr.modify(|_, w| unsafe {
                     w.msirange().bits(range as u8);
-                    #[cfg(not(feature = "wb"))]
+                    #[cfg(not(any(feature = "wb", feature = "wl")))]
                     w.msirgsel().set_bit();
                     w.msion().set_bit()
                 });
@@ -589,7 +647,7 @@ impl Clocks {
                     PllSrc::Msi(range) => {
                         rcc.cr.modify(|_, w| unsafe {
                             w.msirange().bits(range as u8);
-                            #[cfg(not(feature = "wb"))]
+                            #[cfg(not(any(feature = "wb", feature = "wl")))]
                             w.msirgsel().set_bit();
                             w.msion().set_bit()
                         });
@@ -672,7 +730,7 @@ impl Clocks {
             rcc.cr.modify(|_, w| w.pllon().set_bit());
 
             cfg_if! {
-                if #[cfg(not(any(feature = "g0", feature = "g4")))] {
+                if #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))] {
                     if self.sai1_enabled {
                         rcc.cr.modify(|_, w| w.pllsai1on().set_bit());
                         while rcc.cr.read().pllsai1rdy().bit_is_clear() {}
@@ -753,6 +811,10 @@ impl Clocks {
             w.shdhpre().bits(self.hclk4_prescaler as u8)
         });
 
+        #[cfg(feature = "wl")]
+        rcc.extcfgr
+            .modify(|_, w| unsafe { w.shdhpre().bits(self.hclk3_prescaler as u8) });
+
         rcc.cr.modify(|_, w| w.csson().bit(self.security_system));
 
         #[cfg(any(feature = "l4", feature = "g4"))]
@@ -765,7 +827,7 @@ impl Clocks {
 
         // Enable the HSI48 as required, which is used for USB, RNG, etc.
         // Only valid for some devices (On at least L4, and G4.)
-        #[cfg(not(feature = "g0"))]
+        #[cfg(not(any(feature = "g0", feature = "wl")))]
         if self.hsi48_on {
             rcc.crrcr.modify(|_, w| w.hsi48on().set_bit());
             while rcc.crrcr.read().hsi48rdy().bit_is_clear() {}
@@ -809,8 +871,8 @@ impl Clocks {
 
         // Enable and reset System Configuration Controller, ie for interrupts.
         // todo: Is this the right module to do this in?
-        #[cfg(not(feature = "wb"))] // todo: Do interrupts work without enabling syscfg on wb, which
-                                    // todo doesn't have this?
+        #[cfg(not(any(feature = "wb", feature = "wl")))] // todo: Do interrupts work without enabling syscfg on wb, which
+                                                         // todo doesn't have this?
         rcc_en_reset!(apb2, syscfg, rcc);
 
         Ok(())
@@ -1057,27 +1119,24 @@ impl Clocks {
     pub fn pll_is_enabled(&self, rcc: &mut RCC) -> bool {
         rcc.cr.read().pllon().bit_is_set()
     }
-}
 
-// todo: Some extra calculations here, vice doing it once and caching.
-impl ClockCfg for Clocks {
-    fn sysclk(&self) -> u32 {
+    pub fn sysclk(&self) -> u32 {
         let (_, sysclk) = self.calc_sysclock();
         sysclk
     }
 
-    fn hclk(&self) -> u32 {
+    pub fn hclk(&self) -> u32 {
         self.sysclk() / self.hclk_prescaler.value() as u32
     }
 
-    fn systick(&self) -> u32 {
+    pub fn systick(&self) -> u32 {
         self.hclk()
     }
 
     cfg_if! {
-        if #[cfg(feature = "g0")] {
+        if #[cfg(any(feature = "g0", feature = "wl"))] {
             fn usb(&self) -> u32 {
-                unimplemented!("No USB on G0");
+                unimplemented!("No USB on G0 or WL");
             }
         } else if #[cfg(feature = "g4")] {
             fn usb(&self) -> u32 {
@@ -1095,11 +1154,11 @@ impl ClockCfg for Clocks {
         }
     }
 
-    fn apb1(&self) -> u32 {
+    pub fn apb1(&self) -> u32 {
         self.hclk() / self.apb1_prescaler.value() as u32
     }
 
-    fn apb1_timer(&self) -> u32 {
+    pub fn apb1_timer(&self) -> u32 {
         // L4 RM, 6.2.14: The timer clock frequencies are automatically defined by hardware. There are two cases:
         // 1. If the APB prescaler equals 1, the timer clock frequencies are set to the same
         // frequency as that of the APB domain.
@@ -1113,19 +1172,19 @@ impl ClockCfg for Clocks {
 
     cfg_if! {
         if #[cfg(feature = "g0")] {
-            fn apb2(&self) -> u32 {
+            pub fn apb2(&self) -> u32 {
                 unimplemented!("No apb2 on G0");
             }
 
-            fn apb2_timer(&self) -> u32 {
+            pub fn apb2_timer(&self) -> u32 {
                 unimplemented!("No apb2 on G0");
             }
         } else {
-            fn apb2(&self) -> u32 {
+            pub fn apb2(&self) -> u32 {
                 self.hclk() / self.apb2_prescaler.value() as u32
             }
 
-            fn apb2_timer(&self) -> u32 {
+            pub fn apb2_timer(&self) -> u32 {
                 if let ApbPrescaler::Div1 = self.apb2_prescaler {
                     self.apb2()
                 } else {
@@ -1135,7 +1194,7 @@ impl ClockCfg for Clocks {
         }
     }
 
-    fn validate_speeds(&self) -> ClocksValid {
+    pub fn validate_speeds(&self) -> ClocksValid {
         let mut result = ClocksValid::Valid;
 
         #[cfg(feature = "l4")]
@@ -1153,6 +1212,9 @@ impl ClockCfg for Clocks {
         #[cfg(feature = "wb")]
         let max_clock = 64_000_000;
 
+        #[cfg(feature = "wl")]
+        let max_clock = 48_000_000;
+
         // todo: L4+ (ie R, S, P, Q) can go up to 120_000.
 
         #[cfg(any(feature = "l4", feature = "l5", feature = "wb"))]
@@ -1176,6 +1238,10 @@ impl ClockCfg for Clocks {
             return ClocksValid::NotValid;
         }
 
+        // todo: on WB, input src / PlLM * plln Must be between 96 and 344 Mhz.
+        // todo; Cube will validate this. Others probably have a similar restriction.
+        // todo: Put this check here.
+
         // todo: QC these limits
         // todo: Note that this involves repeatedly calculating sysclk.
         // todo. We could work around thsi by calcing it once here.
@@ -1217,9 +1283,11 @@ impl Default for Clocks {
             plln: 85,
             #[cfg(feature = "wb")]
             plln: 64,
-            #[cfg(not(any(feature = "g0", feature = "g4")))]
+            #[cfg(feature = "wl")]
+            plln: 24,
+            #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))]
             pll_sai1_mul: 8,
-            #[cfg(not(any(feature = "g0", feature = "g4")))]
+            #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))]
             pll_sai2_mul: 8,
             #[cfg(not(feature = "wb"))]
             pllr: Pllr::Div2,
@@ -1229,22 +1297,24 @@ impl Default for Clocks {
             hclk_prescaler: HclkPrescaler::Div1,
             #[cfg(feature = "wb")]
             hclk2_prescaler: HclkPrescaler::Div2,
+            #[cfg(feature = "wl")]
+            hclk3_prescaler: HclkPrescaler::Div1,
             #[cfg(feature = "wb")]
             hclk4_prescaler: HclkPrescaler::Div1,
             apb1_prescaler: ApbPrescaler::Div1,
             #[cfg(not(feature = "g0"))]
             apb2_prescaler: ApbPrescaler::Div1,
-            #[cfg(not(feature = "g0"))]
+            #[cfg(not(any(feature = "g0", feature = "wl")))]
             clk48_src: Clk48Src::Hsi48,
-            #[cfg(not(any(feature = "g0", feature = "g4")))]
+            #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))]
             sai1_enabled: false,
-            #[cfg(not(any(feature = "g0", feature = "g4")))]
+            #[cfg(not(any(feature = "g0", feature = "g4", feature = "wl")))]
             sai2_enabled: false,
             hse_bypass: false,
             security_system: false,
-            #[cfg(not(feature = "g0"))]
+            #[cfg(not(any(feature = "g0", feature = "wl")))]
             hsi48_on: false,
-            #[cfg(any(feature = "l4", feature = "l5", feature = "wb"))]
+            #[cfg(any(feature = "l4", feature = "l5", feature = "wb", feature = "wl"))]
             stop_wuck: StopWuck::Msi,
         }
     }
