@@ -108,23 +108,24 @@ cfg_if::cfg_if! {
             // 0: Enter Stop mode when the CPU enters Deepsleep. The regulator status
             // depends on the LPDS bit.
             // 1: Enter Stop mode when the CPU enters Deepsleep.
-            pwr.cr.modify(|_, w| w.pdds().clear_bit());
+            pwr.cr.modify(|_, w| {
+                w.pdds().clear_bit();
+                // Select the voltage regulator mode by configuring LPDS bit in PWR_CR
+                // This bit is set and cleared by software. It works together with the PDDS bit.
+                // 0: Voltage regulator on during Stop mode
+                // 1: Voltage regulator in low-power mode during Stop mode
+                // pwr.cr.modify(|_, w| w.pdds().clear_bit());
+                 w.lpds().set_bit()
+            });
 
-            // Select the voltage regulator mode by configuring LPDS bit in PWR_CR
-            // This bit is set and cleared by software. It works together with the PDDS bit.
-            // 0: Voltage regulator on during Stop mode
-            // 1: Voltage regulator in low-power mode during Stop mode
-            // pwr.cr.modify(|_, w| w.pdds().clear_bit());
-            pwr.cr.modify(|_, w| w.lpds().set_bit());
 
             wfi();
         }
 
-        /// Enter `Standby` mode: the lowest-power of the 3 low-power states avail on the
-        /// STM32f3.
+        /// Enter `Standby` mode.
         /// To exit: WKUP pin rising edge, RTC alarm event’s rising edge, external Reset in
         /// NRST pin, IWDG Reset.
-        /// Ref man, table 21.
+        /// F303 Ref man, table 21.
         /// Run `Clocks::reselect_input()` after to re-enable PLL etc after exiting this mode.
         pub fn standby(scb: &mut SCB, pwr: &mut PWR) {
             // WFI (Wait for Interrupt) or WFE (Wait for Event) while:
@@ -137,11 +138,12 @@ cfg_if::cfg_if! {
             // 0: Enter Stop mode when the CPU enters Deepsleep. The regulator status
             // depends on the LPDS bit.
             // 1: Enter Standby mode when the CPU enters Deepsleep.
-            pwr.cr.modify(|_, w| w.pdds().set_bit());
-
-            // Clear WUF bit in Power Control/Status register (PWR_CSR) (Must do this by setting CWUF bit in
-            // PWR_CR.)
-            pwr.cr.modify(|_, w| w.cwuf().set_bit());
+            pwr.cr.modify(|_, w| {
+                w.pdds().set_bit();
+                // Clear WUF bit in Power Control/Status register (PWR_CSR) (Must do this by setting CWUF bit in
+                // PWR_CR.)
+                w.cwuf().set_bit()
+            });
 
             wfi();
         }
@@ -169,14 +171,17 @@ cfg_if::cfg_if! {
         }
 
 
-        /// Enter `Standby` mode. See L4 table 30. G4 table 47.
+        /// Enter `Standby` mode. See L44 RM table 28. G4 table 47.
         /// Run `Clocks::reselect_input()` after to re-enable PLL etc after exiting this mode.
         pub fn standby(scb: &mut SCB, pwr: &mut PWR) {
             // – SLEEPDEEP bit is set in Cortex®-M4 System Control register
             scb.set_sleepdeep();
+
             // – No interrupt (for WFI) or event (for WFE) is pending
+
             // – LPMS = “011” in PWR_CR1
             pwr.cr1.modify(|_, w| unsafe { w.lpms().bits(0b011) });
+
             // – WUFx bits are cleared in power status register 1 (PWR_SR1)
             // (Clear by setting cwfuf bits in `pwr_scr`.)
             cfg_if! {
@@ -220,6 +225,7 @@ cfg_if::cfg_if! {
             // – WUFx bits are cleared in power status register 1 (PWR_SR1)
             // – The RTC flag corresponding to the chosen wakeup source (RTC Alarm
             // A, RTC Alarm B, RTC wakeup, tamper or timestamp flags) is cleared
+
             wfi();
         }
 
@@ -302,12 +308,13 @@ cfg_if::cfg_if! {
         //     // 0: Enter Stop mode when the CPU enters Deepsleep. The regulator status
         //     // depends on the LPDS bit.
         //     // 1: Enter Standby mode when the CPU enters Deepsleep.
-        //     pwr.cr.modify(|_, w| w.pdds().set_bit());
-        //
-        //     // Clear WUF bit in Power Control/Status register (PWR_CSR) (Must do this by setting CWUF bit in
-        //     // PWR_CR.)
-        //     pwr.cr.modify(|_, w| w.cwuf().set_bit());
-        //
+        //     pwr.cr.modify(|_, w| {
+        //         w.pdds().set_bit();
+        //         // Clear WUF bit in Power Control/Status register (PWR_CSR) (Must do this by setting CWUF bit in
+        //         // PWR_CR.)
+        //         w.cwuf().set_bit()
+        //     });
+
         //     wfi();
         // }
     }
