@@ -1,8 +1,11 @@
 //! USB support, including for simulated COM ports. This module is a thin wrapper required to work with
 //! the `stm32_usbd` crate.
+//!
 //! Requires the `usb` feature.
-//! Used on F303, L4x2, L4x3, L5, G0, and G4. F4, L4x5, L4x6 and H7 use USB use the `usb_otg` module.
-//! For G0 series, only available on G0B0, G0B1, G0C1, which the PAC doesn't yet differentiate.
+//!
+//! Used on F303, L4x2, L4x3, L5, G0, and G4. F4, L4x5, L4x6 and H7 use the `usb_otg` module.
+//! For G0 series, USB is only available on G0B0, G0B1, G0C1, which the PAC doesn't yet differentiate,
+//! and this library doesn't yet support.
 
 use crate::{
     pac::{PWR, RCC},
@@ -19,7 +22,8 @@ use stm32_usbd::UsbPeripheral;
 
 use cfg_if::cfg_if;
 
-/// Represents a Universal Serial Bus (USB) peripheral.
+/// Represents a Universal Serial Bus (USB) peripheral. Functionality is implemented through the
+/// implemented `stm32_usbd::UsbPeripheral` trait.
 pub struct Peripheral {
     /// USB Register Block
     pub usb: USB,
@@ -28,13 +32,8 @@ pub struct Peripheral {
 unsafe impl Sync for Peripheral {}
 
 unsafe impl UsbPeripheral for Peripheral {
-    #[cfg(not(feature = "l4x3"))]
     const REGISTERS: *const () = USB::ptr() as *const ();
 
-    // Workaround due to a PAC issue: https://github.com/stm32-rs/stm32-rs/issues/565
-    #[cfg(feature = "l4x3")]
-    const REGISTERS: *const () = 0x4000_6800 as *const ();
-
     // Embedded pull-up resistor on USB_DP line
     #[cfg(feature = "f3")]
     const DP_PULL_UP_FEATURE: bool = false;
@@ -84,14 +83,7 @@ unsafe impl UsbPeripheral for Peripheral {
 
         cortex_m::interrupt::free(|_| {
             cfg_if! {
-                if #[cfg(feature = "l4x3")] {
-                    // todo: rstr absent or missing in Pac for L4x3. Fixed in next PAC.
-                    rcc.apb1enr1.modify(|_, w| w.usbfsen().set_bit());
-
-                    let rstr_val = rcc.apb1rstr1.read().bits();
-                    rcc.apb1rstr1.modify(|_, w| unsafe { w.bits(rstr_val | (1 << 26)) }); // Set bit 26
-                    rcc.apb1rstr1.modify(|_ , w| unsafe { w.bits(rstr_val & !(1 << 26)) }); // Clear bit 26
-                } else if #[cfg(feature = "l4x2")] {
+                if #[cfg(feature = "l4")] {
                     rcc_en_reset!(apb1, usbfs, rcc);
                 } else if #[cfg(feature = "l5")] {
                     rcc.apb1enr2.modify(|_, w| w.usbfsen().set_bit());
